[lldb-dev] [Bug 39816] New: lldb doesn't show a file of line entry for big project.

via lldb-dev lldb-dev at lists.llvm.org
Tue Nov 27 20:38:40 PST 2018


https://bugs.llvm.org/show_bug.cgi?id=39816

            Bug ID: 39816
           Summary: lldb doesn't show a file of line entry for big
                    project.
           Product: lldb
           Version: 7.0
          Hardware: All
                OS: All
            Status: NEW
          Severity: enhancement
          Priority: P
         Component: All Bugs
          Assignee: lldb-dev at lists.llvm.org
          Reporter: frozenrain.yoo at gmail.com
                CC: llvm-bugs at lists.llvm.org

Created attachment 21167
  --> https://bugs.llvm.org/attachment.cgi?id=21167&action=edit
lldb.patch1

You can see Entry struct in lldb/include/lldb/Symbol/LineTable.h

file_idx type is NOT uint16_t, provide 11 bits. (... uint16_t file_idx : 11,
...)

our object has many header files more than 2048..

if file_idx is 2691..
file_idx = 2691 (0b101010000011) <-- 12bits

file_idx provides 11 bits.
so, file_idx variable changed from 2691(0b101010000011) to 643(0b01010000011).

I think this is a bug.
Fix it. Please.


you can patch following code(attachment files).
please review and submit it.
I don't know this struct data needs serialization..

* patch1
diff --git a/include/lldb/Symbol/LineTable.h b/include/lldb/Symbol/LineTable.h
index a6d4364b9..0300455ec 100644
--- a/include/lldb/Symbol/LineTable.h
+++ b/include/lldb/Symbol/LineTable.h
@@ -311,8 +311,7 @@ protected:
                      ///number information.
     uint16_t column; ///< The column number of the source line, or zero if
there
                      ///is no column information.
-    uint16_t file_idx : 11, ///< The file index into CompileUnit's file table,
-                            ///or zero if there is no file information.
+    uint32_t file_idx : 27,    ///or zero if there is no file information.
         is_start_of_statement : 1, ///< Indicates this entry is the beginning
of
                                    ///a statement.
         is_start_of_basic_block : 1, ///< Indicates this entry is the
beginning



* patch2
diff --git a/include/lldb/Symbol/LineTable.h b/include/lldb/Symbol/LineTable.h
index a6d4364b9..793c3331c 100644
--- a/include/lldb/Symbol/LineTable.h
+++ b/include/lldb/Symbol/LineTable.h
@@ -311,21 +311,20 @@ protected:
                      ///number information.
     uint16_t column; ///< The column number of the source line, or zero if
there
                      ///is no column information.
-    uint16_t file_idx : 11, ///< The file index into CompileUnit's file table,
-                            ///or zero if there is no file information.
-        is_start_of_statement : 1, ///< Indicates this entry is the beginning
of
-                                   ///a statement.
-        is_start_of_basic_block : 1, ///< Indicates this entry is the
beginning
-                                     ///of a basic block.
-        is_prologue_end : 1, ///< Indicates this entry is one (of possibly
many)
-                             ///where execution should be suspended for an
entry
-                             ///breakpoint of a function.
-        is_epilogue_begin : 1, ///< Indicates this entry is one (of possibly
-                               ///many) where execution should be suspended
for
-                               ///an exit breakpoint of a function.
-        is_terminal_entry : 1; ///< Indicates this entry is that of the first
-                               ///byte after the end of a sequence of target
-                               ///machine instructions.
+    uint16_t file_idx;    ///or zero if there is no file information.
+    bool is_start_of_statement; ///< Indicates this entry is the beginning of
+                                ///a statement.
+    bool is_start_of_basic_block; ///< Indicates this entry is the beginning
+                                  ///of a basic block.
+    bool is_prologue_end; ///< Indicates this entry is one (of possibly many)
+                          ///where execution should be suspended for an entry
+                          ///breakpoint of a function.
+    bool is_epilogue_begin; ///< Indicates this entry is one (of possibly
+                            ///many) where execution should be suspended for
+                            ///an exit breakpoint of a function.
+    bool is_terminal_entry; ///< Indicates this entry is that of the first
+                            ///byte after the end of a sequence of target
+                            ///machine instructions.
   };

   struct EntrySearchInfo {

-- 
You are receiving this mail because:
You are the assignee for the bug.
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.llvm.org/pipermail/lldb-dev/attachments/20181128/d2e7b177/attachment.html>


More information about the lldb-dev mailing list